Struct amazon_sp_orders::models::order_items_list::OrderItemsList
source · [−]pub struct OrderItemsList {
pub order_items: Vec<OrderItem>,
pub next_token: Option<String>,
pub amazon_order_id: String,
}Expand description
OrderItemsList : The order items list along with the order ID.
Fields
order_items: Vec<OrderItem>A list of order items.
next_token: Option<String>When present and not empty, pass this string token in the next request to return the next response page.
amazon_order_id: StringAn Amazon-defined order identifier, in 3-7-7 format.
Implementations
sourceimpl OrderItemsList
impl OrderItemsList